@@ -16,4 +16,6 @@ which gnome-autogen.sh || {
     echo "You need to install gnome-common from the GNOME CVS"
     exit 1
 }
-REQUIRED_AUTOMAKE_VERSION=1.9 USE_GNOME2_MACROS=1 . gnome-autogen.sh
+REQUIRED_INTLTOOL_VERSION=0.40.4
+REQUIRED_AUTOMAKE_VERSION=1.9 
+. gnome-autogen.sh
