@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-selection.h 1732 2008-05-18 21:51:38Z chpe $
+ *  $Id$
  */
 
 #ifndef SMART_BOOKMARKS_MOZILLA_SELECTION_H
@@ -23,14 +23,12 @@
 
 #include <glib.h>
 
-#include <epiphany/ephy-embed.h>
+#include <epiphany/epiphany.h>
 
 G_BEGIN_DECLS
 
 char *mozilla_get_selected_text (EphyEmbed *embed);
 
-gboolean mozilla_glue_startup (void);
-
 G_END_DECLS
 
 #endif
